@@ -46,7 +46,7 @@ test_that("heat_map produces a grouped plot", {
 
 test_that("raster=FALSE uses geom_tile", {
     vdiffr::expect_doppelganger(title = "Heatmap using geom_tile",
-                                heat_map(dat, value, x, y, raster = FALSE))
+                                heat_map(dat, value, x, y, raster = FALSE), variant = ggplot2_variant())
 })
 
 test_that("smooth argument produces an interpolated heat_map", {
