@@ -91,6 +91,7 @@ test_that("different interval types work", {
 })
 
 test_that("Testing asreml predictions", {
+    skip_if_not_installed("Matrix")
     load(test_path("data", "asreml_model.Rdata"), .GlobalEnv)
     expect_warning(output <- multiple_comparisons(model.asr,
                                                   classify = "Nitrogen",
@@ -117,7 +118,7 @@ test_that("save produces output", {
 
 test_that("Interaction terms work", {
     load(test_path("data", "asreml_model.Rdata"), .GlobalEnv)
-    skip_if_not(rlang::is_installed("asreml"))
+    skip_if_not_installed("asreml")
     quiet(library(asreml))
     output <- multiple_comparisons(model.asr, classify = "Nitrogen:Variety", pvals = T)
     expect_equal(output$predicted.value,
@@ -168,7 +169,7 @@ test_that("mct removes aliased treatments in aov", {
 
 
 test_that("mct handles aliased results in asreml with a warning", {
-    skip_if_not(rlang::is_installed("asreml"))
+    skip_if_not_installed("asreml")
     quiet(library(asreml))
     load(test_path("data", "asreml_model.Rdata"), envir = .GlobalEnv)
     load(test_path("data", "oats_data.Rdata"), envir = .GlobalEnv)
@@ -223,7 +224,7 @@ test_that("Invalid column name causes an error", {
 })
 
 test_that("Including pred.obj object causes warning", {
-    skip_if_not(rlang::is_installed("asreml"))
+    skip_if_not_installed("asreml")
     quiet(library(asreml))
     load(test_path("data", "asreml_model.Rdata"), envir = .GlobalEnv)
     expect_warning(multiple_comparisons(model.asr, pred.obj = pred.asr, classify = "Nitrogen"),
@@ -231,7 +232,7 @@ test_that("Including pred.obj object causes warning", {
 })
 
 test_that("Providing a random term in classify produces an error.", {
-    skip_if_not(rlang::is_installed("asreml"))
+    skip_if_not_installed("asreml")
     load(test_path("data", "oats_data2.Rdata"), envir = .GlobalEnv)
     expect_error(multiple_comparisons(model2.asr, classify = "Blocks"),
                  "All predicted values are aliased\\. Perhaps you need the `present` argument\\?")
